@@ -28,7 +28,7 @@ __author__ = "Álan Crístoffer"
 __copyright__ = "Copyright 2016, Álan Crístoffer"
 __credits__ = ["Álan Crístoffer"]
 __license__ = "MIT"
-__version__ = "1.3.22"
+__version__ = "1.3.23"
 __maintainer__ = "Álan Crístoffer"
-__email__ = "acristoffers@gmail.com"
+__email__ = "acristoffers@startmail.com"
 __status__ = "Production"
